@@ -11,20 +11,20 @@ use Locale::TextDomain 1.18 qw(test ./LocaleData/);
 # the path to the .mo file ---------^^^^^^^^^^^^^
 
 ## no critic (Ties)
-tie my %__x,   'Tie::Sub', sub { return __x(shift, @_) };
-tie my %__n,   'Tie::Sub', sub { return __n(shift, @_) };
-tie my %__nx,  'Tie::Sub', sub { return __nx(shift, @_) };
-tie my %__xn,  'Tie::Sub', sub { return __xn(shift, @_) };
+tie my %__x,   'Tie::Sub', sub { return __x(shift) };
+tie my %__n,   'Tie::Sub', sub { return __n(shift, shift, shift) };
+tie my %__nx,  'Tie::Sub', sub { return __nx(shift, shift, shift, @_) };
+tie my %__xn,  'Tie::Sub', sub { return __xn(shift, shift, shift, @_) };
 
 tie my %__p,   'Tie::Sub', sub { return __p(shift, shift) };
 tie my %__px,  'Tie::Sub', sub { return __px(shift, shift, @_) };
-tie my %__np,  'Tie::Sub', sub { return __np(shift, shift, @_) };
-tie my %__npx, 'Tie::Sub', sub { return __npx(shift, shift, @_) };
+tie my %__np,  'Tie::Sub', sub { return __np(shift, shift, shift, shift) };
+tie my %__npx, 'Tie::Sub', sub { return __npx(shift, shift, shift, shift, @_) };
 
-tie my %N__,   'Tie::Sub', sub { return [N__(@_)] };
-tie my %N__n,  'Tie::Sub', sub { return [N__n(@_)] };
-tie my %N__p,  'Tie::Sub', sub { return [N__p(@_)] };
-tie my %N__np, 'Tie::Sub', sub { return [N__np(@_)] };
+tie my %N__,   'Tie::Sub', sub { return [N__(shift)] };
+tie my %N__n,  'Tie::Sub', sub { return [N__n(shift, shift, shift)] };
+tie my %N__p,  'Tie::Sub', sub { return [N__p(shift, shift)] };
+tie my %N__np, 'Tie::Sub', sub { return [N__np(shift, shift, shift, shift)] };
 ## use critic (Ties)
 
 # The construct 'shift, @_' or 'shift, shift, @_' is necessary
